==> ejc-businessplan-impl-3.0.0-20230321.070644-132-sources.jar: com/ejianc/business/busniessplan/vo/SubpackagepackgedetailVO.java <==
package com.ejianc.business.busniessplan.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 分包管理策划子表
 * 
 * @author generator
 * 
 */
public class SubpackagepackgedetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String sort; // 序号
    private java.lang.String managerContent; // 管理内容
    private java.lang.String managerAim; // 管理目标
    private java.lang.String managerMeasures; // 管理措施
    private java.lang.String personLiable; // 责任人
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date planCompleteTime; // 计划完成时间
    private java.lang.String planCompleteTimeShow; // 计划完成时间文本显示
    private java.lang.String implementationEffect; // 实施效果

    private java.lang.String errorMsg;

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 管理内容
     */
    public java.lang.String getManagerContent() {
        return managerContent;
    }

    /**
     * 管理内容
     */
    public void setManagerContent(java.lang.String managerContent) {
        this.managerContent = managerContent;
    }
    /**
     * 管理目标
     */
    public java.lang.String getManagerAim() {
        return managerAim;
    }

    /**
     * 管理目标
     */
    public void setManagerAim(java.lang.String managerAim) {
        this.managerAim = managerAim;
    }
    /**
     * 管理措施
     */
    public java.lang.String getManagerMeasures() {
        return managerMeasures;
    }

    /**
     * 管理措施
     */
    public void setManagerMeasures(java.lang.String managerMeasures) {
        this.managerMeasures = managerMeasures;
    }
    /**
     * 责任人
     */
    public java.lang.String getPersonLiable() {
        return personLiable;
    }

    /**
     * 责任人
     */
    public void setPersonLiable(java.lang.String personLiable) {
        this.personLiable = personLiable;
    }
    /**
     * 计划完成时间
     */
    public java.util.Date getPlanCompleteTime() {
        return planCompleteTime;
    }

    /**
     * 计划完成时间
     */
    public void setPlanCompleteTime(java.util.Date planCompleteTime) {
        this.planCompleteTime = planCompleteTime;
    }
    /**
     * 实施效果
     */
    public java.lang.String getImplementationEffect() {
        return implementationEffect;
    }

    /**
     * 实施效果
     */
    public void setImplementationEffect(java.lang.String implementationEffect) {
        this.implementationEffect = implementationEffect;
    }

    public String getPlanCompleteTimeShow() {
        return planCompleteTimeShow;
    }

    public void setPlanCompleteTimeShow(String planCompleteTimeShow) {
        this.planCompleteTimeShow = planCompleteTimeShow;
    }
    
}

==> ejc-businessplan-impl-3.0.0-20241021.063348-193-sources.jar: com/ejianc/business/busniessplan/vo/SubpackagepackgedetailVO.java <==
package com.ejianc.business.busniessplan.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 分包管理策划子表
 *
 * @author generator
 *
 */
public class SubpackagepackgedetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long mid; // 主表id
    private java.lang.String sort; // 序号
    private java.lang.String managerContent; // 管理内容
    private java.lang.String managerAim; // 管理目标
    private java.lang.String managerMeasures; // 管理措施
    private java.lang.String personLiable; // 责任人
    private java.lang.String planCompleteTime; // 计划完成时间
    private java.lang.String planCompleteTimeShow; // 计划完成时间文本显示
    private java.lang.String implementationEffect; // 实施效果

    private java.lang.String errorMsg;

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 管理内容
     */
    public java.lang.String getManagerContent() {
        return managerContent;
    }

    /**
     * 管理内容
     */
    public void setManagerContent(java.lang.String managerContent) {
        this.managerContent = managerContent;
    }
    /**
     * 管理目标
     */
    public java.lang.String getManagerAim() {
        return managerAim;
    }

    /**
     * 管理目标
     */
    public void setManagerAim(java.lang.String managerAim) {
        this.managerAim = managerAim;
    }
    /**
     * 管理措施
     */
    public java.lang.String getManagerMeasures() {
        return managerMeasures;
    }

    /**
     * 管理措施
     */
    public void setManagerMeasures(java.lang.String managerMeasures) {
        this.managerMeasures = managerMeasures;
    }
    /**
     * 责任人
     */
    public java.lang.String getPersonLiable() {
        return personLiable;
    }

    /**
     * 责任人
     */
    public void setPersonLiable(java.lang.String personLiable) {
        this.personLiable = personLiable;
    }

    public String getPlanCompleteTime() {
        return planCompleteTime;
    }

    public void setPlanCompleteTime(String planCompleteTime) {
        this.planCompleteTime = planCompleteTime;
    }

    /**
     * 实施效果
     */
    public java.lang.String getImplementationEffect() {
        return implementationEffect;
    }

    /**
     * 实施效果
     */
    public void setImplementationEffect(java.lang.String implementationEffect) {
        this.implementationEffect = implementationEffect;
    }

    public String getPlanCompleteTimeShow() {
        return planCompleteTimeShow;
    }

    public void setPlanCompleteTimeShow(String planCompleteTimeShow) {
        this.planCompleteTimeShow = planCompleteTimeShow;
    }

}
